==> fluent-0.7.0.tar.gz: fluent/src/Fluent.php <==
<?php

namespace Drupal\fluent;

use Drupal\Core\Entity\EntityBase;

/**
 * Magic class to solve field accessing.
 */
class Fluent {

  /**
   * @var mixed
   */
  private $entity;

  private FieldItemResolver $fieldItemResolver;

  private FieldResolver $fieldResolver;

  /**
   *
   */
  public function __construct(FieldResolver $fieldResolver, FieldItemResolver $fieldItemResolver) {
    $this->fieldResolver = $fieldResolver;
    $this->fieldItemResolver = $fieldItemResolver;
  }

  /**
   * @param mixed $entity
   *   Fieldable entity.
   */
  public function using($entity): Fluent {
    $this->entity = $entity;

    return $this;
  }

  /**
   * @param string $path
   * @param mixed $defaultValue
   *
   * @return mixed
   */
  public function value(string $path, $defaultValue = NULL) {
    $resolution = $this->fieldResolution($path, $this->fieldControl(0, FALSE), $defaultValue);
    return $resolution->getValue();
  }

  /**
   * @param string $path
   * @param $defaultValue
   *
   * @return \Drupal\fluent\Collection
   */
  public function firstValue(string $path, $defaultValue = NULL) {
    return $this->nthValue($path, 0, $defaultValue)->first();
  }

  /**
   * @param string $path
   * @param array $default
   *
   * @return \Drupal\fluent\Collection
   */
  public function values(string $path, array $default = []): Collection {
    return $this->nthValue($path, -1, $default);
  }

  /**
   * @param string $path
   * @param int $position
   * @param $defaultValue
   *
   * @return \Drupal\fluent\Collection
   */
  public function nthValue(string $path, int $position, $defaultValue = NULL) {
    $isMultivalued = FALSE;
    if ($position === -1) {
      $isMultivalued = TRUE;
    }

    $fieldControl = $this->fieldControl($position, $isMultivalued);
    $resolution = $this->fieldResolution($path, $fieldControl, $defaultValue);

    $field = $resolution->getValue();

    if ($field instanceof EntityBase) {
      $collection = [$field];
    }
    else {
      $collection = $field;
    }

    if ($fieldControl->isMultivalued()) {
      return Collection::make($collection);
    } else {
      return $collection;
    }
  }

  /**
   *
   */
  private function fieldResolution($path, FieldControl $fieldControl, $defaultValue) {
    $resolution = $this->fieldResolver->resolve($this->entity, $this->getPath($path), $fieldControl);
    return $this->fieldItemResolver->resolve($resolution, $this->getPath($path), $defaultValue);
  }

  /**
   * Convert path to array.
   */
  private function getPath(string $path): array {
    return explode('.', $path);
  }

  /**
   * Object with the information to control the field accessing.
   */
  private function fieldControl($position, bool $isMultivalued): FieldControl {
    $fieldControl = new FieldControl();
    $fieldControl->setMultivalued($isMultivalued);
    $fieldControl->setPosition($position);

    return $fieldControl;
  }

}

==> fluent-0.9.0.tar.gz: fluent/src/Fluent.php <==
<?php

namespace Drupal\fluent;

use Drupal\Core\Entity\EntityBase;

/**
 * Magic class to solve field accessing.
 */
class Fluent {

  /**
   * @var mixed
   */
  private $entity;

  private FieldItemResolver $fieldItemResolver;

  private FieldResolver $fieldResolver;

  /**
   *
   */
  public function __construct(FieldResolver $fieldResolver, FieldItemResolver $fieldItemResolver) {
    $this->fieldResolver = $fieldResolver;
    $this->fieldItemResolver = $fieldItemResolver;
  }

  /**
   * @param mixed $entity
   *   Fieldable entity.
   */
  public function using($entity): Fluent {
    $this->entity = $entity;

    return $this;
  }

  /**
   * @param string $path
   * @param mixed $defaultValue
   *
   * @return mixed
   */
  public function value(string $path, $defaultValue = NULL) {
    $resolution = $this->fieldResolution($path, $this->fieldControl(0, FALSE), $defaultValue);
    return $resolution->getValue();
  }

  /**
   * @param string $path
   * @param $defaultValue
   *
   * @return \Drupal\fluent\Collection
   */
  public function firstValue(string $path, $defaultValue = NULL) {
    return $this->nthValue($path, 0, $defaultValue);
  }

  /**
   * @param string|array{alias:string, path:string} $path
   * @param array $default
   *
   * @return \Drupal\fluent\Collection
   */
  public function values(string|array $path, array $default = []): Collection {
    if (is_array($path)) {
      $fields = Collection::make($path);

      return $fields->mapWithKeys(function (string $path, string $alias) use ($default) {
        $fieldValue = $this->nthValue($path, -1, $default);

        if ($fieldValue instanceof Collection) {
          $value = $fieldValue->all();
        } else {
          $value = $fieldValue;
        }

        $rename = is_numeric($alias) ? $path:$alias;

        return [
          $rename => $value,
        ];
      });
    } else {
      return $this->nthValue($path, -1, $default);
    }
  }

  /**
   * @param string $path
   * @param int $position
   * @param $defaultValue
   *
   * @return \Drupal\fluent\Collection
   */
  public function nthValue(string $path, int $position, $defaultValue = NULL) {
    $isMultivalued = FALSE;
    if ($position === -1) {
      $isMultivalued = TRUE;
    }

    $fieldControl = $this->fieldControl($position, $isMultivalued);
    $resolution = $this->fieldResolution($path, $fieldControl, $defaultValue);

    $field = $resolution->getValue();

    if ($field instanceof EntityBase) {
      $collection = [$field];
    }
    else {
      $collection = $field;
    }

    if (is_array($collection)) {
      return Collection::make($collection);
    } else {
      return $collection;
    }
  }

  /**
   *
   */
  private function fieldResolution($path, FieldControl $fieldControl, $defaultValue) {
    $resolution = $this->fieldResolver->resolve($this->entity, $this->getPath($path), $fieldControl);
    return $this->fieldItemResolver->resolve($resolution, $this->getPath($path), $defaultValue);
  }

  /**
   * Convert path to array.
   */
  private function getPath(string $path): array {
    $path = preg_replace('/[^a-zA-Z\d._]/', '', $path);
    return explode('.', $path);
  }

  /**
   * Object with the information to control the field accessing.
   */
  private function fieldControl($position, bool $isMultivalued): FieldControl {
    $fieldControl = new FieldControl();
    $fieldControl->setMultivalued($isMultivalued);
    $fieldControl->setPosition($position);

    return $fieldControl;
  }

}
